Welcome to Ladybug's documentation!
===================================

.. image:: http://www.ladybug.tools/assets/img/ladybug.png

Ladybug is a Python library to load, analyze and modify EnergyPlus Weather files (epw).

You can download epw files from `EPWMap <http://www.ladybug.tools/epwmap/>`_.

Installation
============

``pip install -U ladybug-core``


CLI Docs
=============

For command line interface documentation and API documentation see the pages below.


.. toctree::
   :maxdepth: 2

   cli/index


ladybug
=======

.. toctree::
  :maxdepth: 4

  modules

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
